Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(677)

Unified Diff: chrome/browser/sync/glue/model_associator.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/model_associator.h
diff --git a/chrome/browser/sync/glue/model_associator.h b/chrome/browser/sync/glue/model_associator.h
index dadd86da597c085bba57de37bb33cb05323fc4ba..0e7dc61c7c11316e5f94ba49b9df8820c8b197ee 100644
--- a/chrome/browser/sync/glue/model_associator.h
+++ b/chrome/browser/sync/glue/model_associator.h
@@ -11,7 +11,7 @@
#include "sync/api/sync_error.h"
#include "sync/internal_api/public/syncable/model_type.h"
-namespace csync {
+namespace syncer {
class BaseNode;
}
@@ -29,10 +29,10 @@ class AssociatorInterface {
// should be identical and corresponding. Returns true on
// success. On failure of this step, we should abort the sync
// operation and report an error to the user.
- virtual csync::SyncError AssociateModels() = 0;
+ virtual syncer::SyncError AssociateModels() = 0;
// Clears all the associations between the chrome and sync models.
- virtual csync::SyncError DisassociateModels() = 0;
+ virtual syncer::SyncError DisassociateModels() = 0;
// The has_nodes out parameter is set to true if the sync model has
// nodes other than the permanent tagged nodes. The method may
@@ -66,7 +66,7 @@ class PerDataTypeAssociatorInterface : public AssociatorInterface {
public:
virtual ~PerDataTypeAssociatorInterface() {}
// Returns sync id for the given chrome model id.
// Returns csync::kInvalidId if the sync node is not found for the given
// chrome id.
virtual int64 GetSyncIdFromChromeId(const IDType& id) = 0;
@@ -79,7 +79,7 @@ class PerDataTypeAssociatorInterface : public AssociatorInterface {
// if the initialization of sync node fails.
virtual bool InitSyncNodeFromChromeId(
const IDType& node_id,
- csync::BaseNode* sync_node) = 0;
+ syncer::BaseNode* sync_node) = 0;
// Associates the given chrome node with the given sync id.
virtual void Associate(const Node* node, int64 sync_id) = 0;
« no previous file with comments | « chrome/browser/sync/glue/model_association_manager_unittest.cc ('k') | chrome/browser/sync/glue/model_associator_mock.h » ('j') | no next file with comments »
@@ -66,7 +66,7 @@ class PerDataTypeAssociatorInterface : public AssociatorInterface {
virtual ~PerDataTypeAssociatorInterface() {}
// Returns sync id for the given chrome model id.
- // Returns csync::kInvalidId if the sync node is not found for the given
+ // Returns syncer::kInvalidId if the sync node is not found for the given
// chrome id.
virtual int64 GetSyncIdFromChromeId(const IDType& id) = 0;

Powered by Google App Engine
This is Rietveld 408576698